@@ -1,6 +1,4 @@
-# -*- coding: utf-8  -*-
-#
-# Copyright (C) 2012-2019 Ben Kurtovic <ben.kurtovic@gmail.com>
+# Copyright (C) 2012-2020 Ben Kurtovic <ben.kurtovic@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,16 +21,16 @@
 """
 `mwparserfromhell <https://github.com/earwig/mwparserfromhell>`_ (the MediaWiki
 Parser from Hell) is a Python package that provides an easy-to-use and
-outrageously powerful parser for `MediaWiki <http://mediawiki.org>`_ wikicode.
+outrageously powerful parser for `MediaWiki <https://www.mediawiki.org>`_ wikicode.
 """
 
 __author__ = "Ben Kurtovic"
-__copyright__ = "Copyright (C) 2012-2019 Ben Kurtovic"
+__copyright__ = "Copyright (C) 2012-2020 Ben Kurtovic"
 __license__ = "MIT License"
-__version__ = "0.5.4"
+__version__ = "0.6"
 __email__ = "ben.kurtovic@gmail.com"
 
-from . import (compat, definitions, nodes, parser, smart_list, string_mixin,
+from . import (definitions, nodes, parser, smart_list, string_mixin,
                utils, wikicode)
 
 parse = utils.parse_anything
