@@ -29,23 +29,16 @@ SOFTWARE.
 /*
     Internal allocation function for textbuffers.
 */
-static int internal_alloc(Textbuffer* self, Unicode maxchar)
+static int internal_alloc(Textbuffer* self, Py_UCS4 maxchar)
 {
     self->capacity = INITIAL_CAPACITY;
     self->length = 0;
 
-#ifdef PEP_393
     self->object = PyUnicode_New(self->capacity, maxchar);
     if (!self->object)
         return -1;
     self->kind = PyUnicode_KIND(self->object);
     self->data = PyUnicode_DATA(self->object);
-#else
-    (void) maxchar;  // Unused
-    self->data = malloc(sizeof(Unicode) * self->capacity);
-    if (!self->data)
-        return -1;
-#endif
 
     return 0;
 }
@@ -55,11 +48,7 @@ static int internal_alloc(Textbuffer* self, Unicode maxchar)
 */
 static void internal_dealloc(Textbuffer* self)
 {
-#ifdef PEP_393
     Py_DECREF(self->object);
-#else
-    free(self->data);
-#endif
 }
 
 /*
@@ -67,7 +56,6 @@ static void internal_dealloc(Textbuffer* self)
 */
 static int internal_resize(Textbuffer* self, Py_ssize_t new_cap)
 {
-#ifdef PEP_393
     PyObject *newobj;
     void *newdata;
 
@@ -79,10 +67,6 @@ static int internal_resize(Textbuffer* self, Py_ssize_t new_cap)
     Py_DECREF(self->object);
     self->object = newobj;
     self->data = newdata;
-#else
-    if (!(self->data = realloc(self->data, sizeof(Unicode) * new_cap)))
-        return -1;
-#endif
 
     self->capacity = new_cap;
     return 0;
@@ -94,11 +78,9 @@ static int internal_resize(Textbuffer* self, Py_ssize_t new_cap)
 Textbuffer* Textbuffer_new(TokenizerInput* text)
 {
     Textbuffer* self = malloc(sizeof(Textbuffer));
-    Unicode maxchar = 0;
+    Py_UCS4 maxchar = 0;
 
-#ifdef PEP_393
     maxchar = PyUnicode_MAX_CHAR_VALUE(text->object);
-#endif
 
     if (!self)
         goto fail_nomem;
@@ -127,11 +109,9 @@ void Textbuffer_dealloc(Textbuffer* self)
 */
 int Textbuffer_reset(Textbuffer* self)
 {
-    Unicode maxchar = 0;
+    Py_UCS4 maxchar = 0;
 
-#ifdef PEP_393
     maxchar = PyUnicode_MAX_CHAR_VALUE(self->object);
-#endif
 
     internal_dealloc(self);
     if (internal_alloc(self, maxchar))
@@ -142,18 +122,14 @@ int Textbuffer_reset(Textbuffer* self)
 /*
     Write a Unicode codepoint to the given textbuffer.
 */
-int Textbuffer_write(Textbuffer* self, Unicode code)
+int Textbuffer_write(Textbuffer* self, Py_UCS4 code)
 {
     if (self->length >= self->capacity) {
         if (internal_resize(self, self->capacity * RESIZE_FACTOR) < 0)
             return -1;
     }
 
-#ifdef PEP_393
     PyUnicode_WRITE(self->kind, self->data, self->length++, code);
-#else
-    self->data[self->length++] = code;
-#endif
 
     return 0;
 }
@@ -163,13 +139,9 @@ int Textbuffer_write(Textbuffer* self, Unicode code)
 
     This function does not check for bounds.
 */
-Unicode Textbuffer_read(Textbuffer* self, Py_ssize_t index)
+Py_UCS4 Textbuffer_read(Textbuffer* self, Py_ssize_t index)
 {
-#ifdef PEP_393
     return PyUnicode_READ(self->kind, self->data, index);
-#else
-    return self->data[index];
-#endif
 }
 
 /*
@@ -177,11 +149,7 @@ Unicode Textbuffer_read(Textbuffer* self, Py_ssize_t index)
 */
 PyObject* Textbuffer_render(Textbuffer* self)
 {
-#ifdef PEP_393
     return PyUnicode_FromKindAndData(self->kind, self->data, self->length);
-#else
-    return PyUnicode_FromUnicode(self->data, self->length);
-#endif
 }
 
 /*
@@ -196,14 +164,9 @@ int Textbuffer_concat(Textbuffer* self, Textbuffer* other)
             return -1;
     }
 
-#ifdef PEP_393
     assert(self->kind == other->kind);
     memcpy(((Py_UCS1*) self->data) + self->kind * self->length, other->data,
            other->length * other->kind);
-#else
-    memcpy(self->data + self->length, other->data,
-           other->length * sizeof(Unicode));
-#endif
 
     self->length = newlen;
     return 0;
@@ -215,18 +178,12 @@ int Textbuffer_concat(Textbuffer* self, Textbuffer* other)
 void Textbuffer_reverse(Textbuffer* self)
 {
     Py_ssize_t i, end = self->length - 1;
-    Unicode tmp;
+    Py_UCS4 tmp;
 
     for (i = 0; i < self->length / 2; i++) {
-#ifdef PEP_393
         tmp = PyUnicode_READ(self->kind, self->data, i);
         PyUnicode_WRITE(self->kind, self->data, i,
                         PyUnicode_READ(self->kind, self->data, end - i));
         PyUnicode_WRITE(self->kind, self->data, end - i, tmp);
-#else
-        tmp = self->data[i];
-        self->data[i] = self->data[end - i];
-        self->data[end - i] = tmp;
-#endif
     }
 }
