@@ -38,14 +38,14 @@ void Tokenizer_free_bad_route_tree(Tokenizer*);
 
 int Tokenizer_emit_token(Tokenizer*, PyObject*, int);
 int Tokenizer_emit_token_kwargs(Tokenizer*, PyObject*, PyObject*, int);
-int Tokenizer_emit_char(Tokenizer*, Unicode);
+int Tokenizer_emit_char(Tokenizer*, Py_UCS4);
 int Tokenizer_emit_text(Tokenizer*, const char*);
 int Tokenizer_emit_textbuffer(Tokenizer*, Textbuffer*);
 int Tokenizer_emit_all(Tokenizer*, PyObject*);
 int Tokenizer_emit_text_then_stack(Tokenizer*, const char*);
 
-Unicode Tokenizer_read(Tokenizer*, Py_ssize_t);
-Unicode Tokenizer_read_backwards(Tokenizer*, Py_ssize_t);
+Py_UCS4 Tokenizer_read(Tokenizer*, Py_ssize_t);
+Py_UCS4 Tokenizer_read_backwards(Tokenizer*, Py_ssize_t);
 
 /* Macros */
 
