@@ -1,5 +1,3 @@
-# -*- coding: utf-8  -*-
-#
 # Copyright (C) 2012-2019 Ben Kurtovic <ben.kurtovic@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -20,10 +18,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import unicode_literals
 import unittest
 
-from mwparserfromhell.compat import py3k
 from mwparserfromhell.nodes import (Argument, Comment, ExternalLink, Heading,
                                     HTMLEntity, Tag, Template, Text, Wikilink)
 from mwparserfromhell.nodes.extras import Attribute, Parameter
@@ -428,9 +424,8 @@ class TestBuilder(TreeEqualityTestCase):
             [tokens.TagOpenOpen()]
         ]
 
-        func = self.assertRaisesRegex if py3k else self.assertRaisesRegexp
         msg = r"_handle_token\(\) got unexpected TemplateClose"
-        func(ParserError, msg, self.builder.build, [tokens.TemplateClose()])
+        self.assertRaisesRegex(ParserError, msg, self.builder.build, [tokens.TemplateClose()])
         for test in missing_closes:
             self.assertRaises(ParserError, self.builder.build, test)
 
