@@ -1,6 +1,4 @@
-# -*- coding: utf-8  -*-
-#
-# Copyright (C) 2012-2016 Ben Kurtovic <ben.kurtovic@gmail.com>
+# Copyright (C) 2012-2020 Ben Kurtovic <ben.kurtovic@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,10 +18,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import unicode_literals
 import unittest
 
-from mwparserfromhell.compat import str
 from mwparserfromhell.nodes import Comment
 
 from ._test_tree_equality import TreeEqualityTestCase
@@ -31,8 +27,8 @@ from ._test_tree_equality import TreeEqualityTestCase
 class TestComment(TreeEqualityTestCase):
     """Test cases for the Comment node."""
 
-    def test_unicode(self):
-        """test Comment.__unicode__()"""
+    def test_str(self):
+        """test Comment.__str__()"""
         node = Comment("foobar")
         self.assertEqual("<!--foobar-->", str(node))
 
