@@ -1,6 +1,4 @@
-# -*- coding: utf-8  -*-
-#
-# Copyright (C) 2012-2016 Ben Kurtovic <ben.kurtovic@gmail.com>
+# Copyright (C) 2012-2020 Ben Kurtovic <ben.kurtovic@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,10 +18,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import unicode_literals
 import unittest
 
-from mwparserfromhell.compat import str
 from mwparserfromhell.nodes import ExternalLink, Text
 
 from ._test_tree_equality import TreeEqualityTestCase, wrap, wraptext
@@ -31,8 +27,8 @@ from ._test_tree_equality import TreeEqualityTestCase, wrap, wraptext
 class TestExternalLink(TreeEqualityTestCase):
     """Test cases for the ExternalLink node."""
 
-    def test_unicode(self):
-        """test ExternalLink.__unicode__()"""
+    def test_str(self):
+        """test ExternalLink.__str__()"""
         node = ExternalLink(wraptext("http://example.com/"), brackets=False)
         self.assertEqual("http://example.com/", str(node))
         node2 = ExternalLink(wraptext("http://example.com/"))
