@@ -1,6 +1,4 @@
-# -*- coding: utf-8  -*-
-#
-# Copyright (C) 2012-2016 Ben Kurtovic <ben.kurtovic@gmail.com>
+# Copyright (C) 2012-2020 Ben Kurtovic <ben.kurtovic@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,19 +18,17 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import unicode_literals
 from sys import getdefaultencoding
 from types import GeneratorType
 import unittest
 
-from mwparserfromhell.compat import bytes, py3k, range, str
 from mwparserfromhell.string_mixin import StringMixIn
 
 class _FakeString(StringMixIn):
     def __init__(self, data):
         self._data = data
 
-    def __unicode__(self):
+    def __str__(self):
         return self._data
 
 
@@ -42,18 +38,16 @@ class TestStringMixIn(unittest.TestCase):
     def test_docs(self):
         """make sure the various methods of StringMixIn have docstrings"""
         methods = [
-            "capitalize", "center", "count", "encode", "endswith",
-            "expandtabs", "find", "format", "index", "isalnum", "isalpha",
-            "isdecimal", "isdigit", "islower", "isnumeric", "isspace",
-            "istitle", "isupper", "join", "ljust", "lower", "lstrip",
-            "partition", "replace", "rfind", "rindex", "rjust", "rpartition",
-            "rsplit", "rstrip", "split", "splitlines", "startswith", "strip",
-            "swapcase", "title", "translate", "upper", "zfill"]
-        if py3k:
-            methods.extend(["casefold", "format_map", "isidentifier", "isprintable",
-                            "maketrans"])
-        else:
-            methods.append("decode")
+            "capitalize", "casefold", "center", "count", "encode", "endswith",
+            "expandtabs", "find", "format", "format_map", "index", "isalnum",
+            "isalpha", "isdecimal", "isdigit", "isidentifier", "islower",
+            "isnumeric", "isprintable", "isspace", "istitle", "isupper",
+            "join", "ljust", "lower", "lstrip", "maketrans", "partition",
+            "replace", "rfind", "rindex", "rjust", "rpartition", "rsplit",
+            "rstrip", "split", "splitlines", "startswith", "strip", "swapcase",
+            "title", "translate", "upper", "zfill"
+        ]
+
         for meth in methods:
             expected = getattr("foo", meth).__doc__
             actual = getattr(_FakeString("foo"), meth).__doc__
@@ -64,17 +58,11 @@ class TestStringMixIn(unittest.TestCase):
         fstr = _FakeString("fake string")
         self.assertEqual(str(fstr), "fake string")
         self.assertEqual(bytes(fstr), b"fake string")
-        if py3k:
-            self.assertEqual(repr(fstr), "'fake string'")
-        else:
-            self.assertEqual(repr(fstr), b"u'fake string'")
+        self.assertEqual(repr(fstr), "'fake string'")
 
         self.assertIsInstance(str(fstr), str)
         self.assertIsInstance(bytes(fstr), bytes)
-        if py3k:
-            self.assertIsInstance(repr(fstr), str)
-        else:
-            self.assertIsInstance(repr(fstr), bytes)
+        self.assertIsInstance(repr(fstr), str)
 
     def test_comparisons(self):
         """make sure comparison operators work"""
@@ -139,7 +127,7 @@ class TestStringMixIn(unittest.TestCase):
         self.assertIsInstance(gen2, GeneratorType)
 
         out = []
-        for i in range(len(str1)):
+        for _ in range(len(str1)):
             out.append(next(gen1))
         self.assertRaises(StopIteration, next, gen1)
         self.assertEqual(expected, out)
@@ -179,14 +167,6 @@ class TestStringMixIn(unittest.TestCase):
         self.assertEqual(1, str1.count("r", 5, 9))
         self.assertEqual(0, str1.count("r", 5, 7))
 
-        if not py3k:
-            str2 = _FakeString("fo")
-            self.assertEqual(str1, str1.decode())
-            actual = _FakeString("\\U00010332\\U0001033f\\U00010344")
-            self.assertEqual("𐌲𐌿𐍄", actual.decode("unicode_escape"))
-            self.assertRaises(UnicodeError, str2.decode, "punycode")
-            self.assertEqual("", str2.decode("punycode", "ignore"))
-
         str3 = _FakeString("𐌲𐌿𐍄")
         actual = b"\xF0\x90\x8C\xB2\xF0\x90\x8C\xBF\xF0\x90\x8D\x84"
         self.assertEqual(b"fake string", str1.encode())
@@ -233,10 +213,9 @@ class TestStringMixIn(unittest.TestCase):
         self.assertEqual("foobarbazbuzz", str7.format("bar", abc="baz"))
         self.assertRaises(IndexError, str8.format, "abc")
 
-        if py3k:
-            self.assertEqual("fake string", str1.format_map({}))
-            self.assertEqual("foobarbaz", str6.format_map({"abc": "bar"}))
-            self.assertRaises(ValueError, str5.format_map, {0: "abc"})
+        self.assertEqual("fake string", str1.format_map({}))
+        self.assertEqual("foobarbaz", str6.format_map({"abc": "bar"}))
+        self.assertRaises(ValueError, str5.format_map, {0: "abc"})
 
         self.assertEqual(3, str1.index("e"))
         self.assertRaises(ValueError, str1.index, "z")
@@ -269,11 +248,10 @@ class TestStringMixIn(unittest.TestCase):
         self.assertFalse(str13.isdigit())
         self.assertTrue(str14.isdigit())
 
-        if py3k:
-            self.assertTrue(str9.isidentifier())
-            self.assertTrue(str10.isidentifier())
-            self.assertFalse(str11.isidentifier())
-            self.assertFalse(str12.isidentifier())
+        self.assertTrue(str9.isidentifier())
+        self.assertTrue(str10.isidentifier())
+        self.assertFalse(str11.isidentifier())
+        self.assertFalse(str12.isidentifier())
 
         str15 = _FakeString("")
         str16 = _FakeString("FooBar")
@@ -286,13 +264,12 @@ class TestStringMixIn(unittest.TestCase):
         self.assertTrue(str13.isnumeric())
         self.assertTrue(str14.isnumeric())
 
-        if py3k:
-            str16B = _FakeString("\x01\x02")
-            self.assertTrue(str9.isprintable())
-            self.assertTrue(str13.isprintable())
-            self.assertTrue(str14.isprintable())
-            self.assertTrue(str15.isprintable())
-            self.assertFalse(str16B.isprintable())
+        str16B = _FakeString("\x01\x02")
+        self.assertTrue(str9.isprintable())
+        self.assertTrue(str13.isprintable())
+        self.assertTrue(str14.isprintable())
+        self.assertTrue(str15.isprintable())
+        self.assertFalse(str16B.isprintable())
 
         str17 = _FakeString(" ")
         str18 = _FakeString("\t     \t \r\n")
@@ -323,10 +300,9 @@ class TestStringMixIn(unittest.TestCase):
         self.assertEqual("", str15.lower())
         self.assertEqual("foobar", str16.lower())
         self.assertEqual("ß", str22.lower())
-        if py3k:
-            self.assertEqual("", str15.casefold())
-            self.assertEqual("foobar", str16.casefold())
-            self.assertEqual("ss", str22.casefold())
+        self.assertEqual("", str15.casefold())
+        self.assertEqual("foobar", str16.casefold())
+        self.assertEqual("ss", str22.casefold())
 
         str23 = _FakeString("  fake string  ")
         self.assertEqual("fake string", str1.lstrip())
@@ -372,9 +348,8 @@ class TestStringMixIn(unittest.TestCase):
         self.assertEqual(actual, str25.rsplit(None, 3))
         actual = ["   this is a   sentence with", "", "whitespace", ""]
         self.assertEqual(actual, str25.rsplit(" ", 3))
-        if py3k:
-            actual = ["   this is a", "sentence", "with", "whitespace"]
-            self.assertEqual(actual, str25.rsplit(maxsplit=3))
+        actual = ["   this is a", "sentence", "with", "whitespace"]
+        self.assertEqual(actual, str25.rsplit(maxsplit=3))
 
         self.assertEqual("fake string", str1.rstrip())
         self.assertEqual("  fake string", str23.rstrip())
@@ -390,9 +365,8 @@ class TestStringMixIn(unittest.TestCase):
         self.assertEqual(actual, str25.split(None, 3))
         actual = ["", "", "", "this is a   sentence with  whitespace "]
         self.assertEqual(actual, str25.split(" ", 3))
-        if py3k:
-            actual = ["this", "is", "a", "sentence with  whitespace "]
-            self.assertEqual(actual, str25.split(maxsplit=3))
+        actual = ["this", "is", "a", "sentence with  whitespace "]
+        self.assertEqual(actual, str25.split(maxsplit=3))
 
         str26 = _FakeString("lines\nof\ntext\r\nare\r\npresented\nhere")
         self.assertEqual(["lines", "of", "text", "are", "presented", "here"],
@@ -411,17 +385,13 @@ class TestStringMixIn(unittest.TestCase):
 
         self.assertEqual("Fake String", str1.title())
 
-        if py3k:
-            table1 = StringMixIn.maketrans({97: "1", 101: "2", 105: "3",
-                                            111: "4", 117: "5"})
-            table2 = StringMixIn.maketrans("aeiou", "12345")
-            table3 = StringMixIn.maketrans("aeiou", "12345", "rts")
-            self.assertEqual("f1k2 str3ng", str1.translate(table1))
-            self.assertEqual("f1k2 str3ng", str1.translate(table2))
-            self.assertEqual("f1k2 3ng", str1.translate(table3))
-        else:
-            table = {97: "1", 101: "2", 105: "3", 111: "4", 117: "5"}
-            self.assertEqual("f1k2 str3ng", str1.translate(table))
+        table1 = StringMixIn.maketrans({97: "1", 101: "2", 105: "3",
+                                        111: "4", 117: "5"})
+        table2 = StringMixIn.maketrans("aeiou", "12345")
+        table3 = StringMixIn.maketrans("aeiou", "12345", "rts")
+        self.assertEqual("f1k2 str3ng", str1.translate(table1))
+        self.assertEqual("f1k2 str3ng", str1.translate(table2))
+        self.assertEqual("f1k2 3ng", str1.translate(table3))
 
         self.assertEqual("", str15.upper())
         self.assertEqual("FOOBAR", str16.upper())
